@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -108,7 +108,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -200,6 +200,18 @@ Return the duration value of the given name.
 
 =head2 motif
 
+  $motif = $mdp->motif;
+
+Generate a rhythmic phrase of the given B<size>.
+
+Currently, this is constructed by selecting a B<pool> duration at
+random, that fits into the size remaining after each application, in a
+loop until the B<size> is met.
+
+=head1 TO DO
+
+Give ->motif a code reference to select a pool duration instead of "at random."
+
 =head1 SEE ALSO
 
 The F<t/t/01-methods.t> and F<eg/motif> code in this distribution.
